:mod:`exspy.data`
-----------------

.. currentmodule:: exspy.data

.. autosummary::

    EDS_SEM_TM002
    EDS_TEM_FePt_nanoparticles
    EELS_low_loss
    EELS_MnFe
    eelsdb

.. automodule:: exspy.data
   :members: